Mesa (master): mesa: fix some comments in sampler object code

Brian Paul brianp at kemper.freedesktop.org
Wed Apr 13 13:39:27 UTC 2011


Module: Mesa
Branch: master
Commit: 75d585e5447fb90a27e9ddb6c60f3560db1512f4
URL:    http://cgit.freedesktop.org/mesa/mesa/commit/?id=75d585e5447fb90a27e9ddb6c60f3560db1512f4

Author: Brian Paul <brianp at vmware.com>
Date:   Wed Apr 13 07:35:25 2011 -0600

mesa: fix some comments in sampler object code

---

 src/mesa/main/samplerobj.c |    8 ++++----
 1 files changed, 4 insertions(+), 4 deletions(-)

diff --git a/src/mesa/main/samplerobj.c b/src/mesa/main/samplerobj.c
index 55acb6d..2d3879c 100644
--- a/src/mesa/main/samplerobj.c
+++ b/src/mesa/main/samplerobj.c
@@ -63,7 +63,7 @@ _mesa_reference_sampler_object(struct gl_context *ctx,
       return;
 
    if (*ptr) {
       /* Unreference the old buffer */
       GLboolean deleteFlag = GL_FALSE;
       struct gl_sampler_object *oldSamp = *ptr;
 
@@ -90,9 +90,9 @@ _mesa_reference_sampler_object(struct gl_context *ctx,
       /* reference new sampler */
       /*_glthread_LOCK_MUTEX(samp->Mutex);*/
       if (samp->RefCount == 0) {
          /* this buffer's being deleted (look just above) */
          /* Not sure this can every really happen.  Warn if it does. */
-         _mesa_problem(NULL, "referencing deleted buffer object");
+         _mesa_problem(NULL, "referencing deleted sampler object");
          *ptr = NULL;
       }
       else {
@@ -281,7 +281,7 @@ _mesa_BindSampler(GLuint unit, GLuint sampler)
 
 
 /**
- * Check if a coordinate wrap mode is supported for the texture target.
+ * Check if a coordinate wrap mode is legal.
  * \return GL_TRUE if legal, GL_FALSE otherwise
  */
 static GLboolean 
@@ -63,7 +63,7 @@ _mesa_reference_sampler_object(struct gl_context *ctx,
 
    if (*ptr) {
-      /* Unreference the old buffer */
+      /* Unreference the old sampler */
       GLboolean deleteFlag = GL_FALSE;
       struct gl_sampler_object *oldSamp = *ptr;
@@ -90,9 +90,9 @@ _mesa_reference_sampler_object(struct gl_context *ctx,
       /*_glthread_LOCK_MUTEX(samp->Mutex);*/
       if (samp->RefCount == 0) {
-         /* this buffer's being deleted (look just above) */
+         /* this sampler's being deleted (look just above) */
          /* Not sure this can every really happen.  Warn if it does. */




More information about the mesa-commit mailing list